@@ -181,3 +181,6 @@ class SpotifyInternal:
         #     operation_name, variables, utils.hash(endpoint))
         # return self._get(url)
         return self.spotify.playlist(playlist_id)
+
+    def user(self, user_id: str):
+        return self.spotify.user(user_id)
